python3-django: fix CVE-2025-57833

Reference:
https://nvd.nist.gov/vuln/detail/CVE-2025-57833

Upstream-patch:
31334e6965

Signed-off-by: Saravanan <saravanan.kadambathursubramaniyam@windriver.com>
Signed-off-by: Gyorgy Sarvari <skandigraun@gmail.com>
This commit is contained in:
Saravanan
2025-11-30 17:18:59 +05:30
committed by Gyorgy Sarvari
parent 0b554678b6
commit 21d389c8f9
4 changed files with 207 additions and 0 deletions

View File

@@ -0,0 +1,110 @@
From 31334e6965ad136a5e369993b01721499c5d1a92 Mon Sep 17 00:00:00 2001
From: Jake Howard <git@theorangeone.net>
Date: Wed, 13 Aug 2025 14:13:42 +0200
Subject: [PATCH] Fixed CVE-2025-57833 -- Protected FilteredRelation against
SQL injection in column aliases.
Thanks Eyal Gabay (EyalSec) for the report.
Backport of 51711717098d3f469f795dfa6bc3758b24f69ef7 from main.
CVE: CVE-2025-57833
Upstream-Status: Backport
https://github.com/django/django/commit/31334e6965ad136a5e369993b01721499c5d1a92
Signed-off-by: Jake Howard <git@theorangeone.net>
Signed-off-by: Saravanan <saravanan.kadambathursubramaniyam@windriver.com>
---
django/db/models/sql/query.py | 1 +
docs/releases/3.2.25.txt | 7 +++++++
tests/annotations/tests.py | 25 ++++++++++++++++++++++++-
3 files changed, 32 insertions(+), 1 deletion(-)
diff --git a/django/db/models/sql/query.py b/django/db/models/sql/query.py
index 230b6fa..e56ff81 100644
--- a/django/db/models/sql/query.py
+++ b/django/db/models/sql/query.py
@@ -1466,6 +1466,7 @@ class Query(BaseExpression):
return target_clause
def add_filtered_relation(self, filtered_relation, alias):
+ self.check_alias(alias)
filtered_relation.alias = alias
lookups = dict(get_children_from_q(filtered_relation.condition))
relation_lookup_parts, relation_field_parts, _ = self.solve_lookup_type(filtered_relation.relation_name)
diff --git a/docs/releases/3.2.25.txt b/docs/releases/3.2.25.txt
index 93ab341..a2a58b5 100644
--- a/docs/releases/3.2.25.txt
+++ b/docs/releases/3.2.25.txt
@@ -33,6 +33,13 @@ which has now been updated to define a ``max_length`` of 39 characters.
The :class:`django.db.models.GenericIPAddressField` model field was not
affected.
+CVE-2025-57833: Potential SQL injection in ``FilteredRelation`` column aliases
+==============================================================================
+
+:class:`.FilteredRelation` was subject to SQL injection in column aliases,
+using a suitably crafted dictionary, with dictionary expansion, as the
+``**kwargs`` passed to :meth:`.QuerySet.annotate` or :meth:`.QuerySet.alias`.
+
Bugfixes
========
--
2.40.0

View File

@@ -0,0 +1,95 @@
From 31334e6965ad136a5e369993b01721499c5d1a92 Mon Sep 17 00:00:00 2001
From: Jake Howard <git@theorangeone.net>
Date: Wed, 13 Aug 2025 14:13:42 +0200
Subject: [PATCH] Fixed CVE-2025-57833 -- Protected FilteredRelation against
SQL injection in column aliases.
Thanks Eyal Gabay (EyalSec) for the report.
Backport of 51711717098d3f469f795dfa6bc3758b24f69ef7 from main.
CVE: CVE-2025-57833
Upstream-Status: Backport
https://github.com/django/django/commit/31334e6965ad136a5e369993b01721499c5d1a92
Signed-off-by: Jake Howard <git@theorangeone.net>
Signed-off-by: Saravanan <saravanan.kadambathursubramaniyam@windriver.com>
%% original patch: CVE-2025-57833.patch
---
django/db/models/sql/query.py | 1 +
docs/releases/2.2.28.txt | 7 +++++++
tests/annotations/tests.py | 18 ++++++++++++++++--
3 files changed, 24 insertions(+), 2 deletions(-)
diff --git a/django/db/models/sql/query.py b/django/db/models/sql/query.py
index 9b054bd..96a6f5f 100644
--- a/django/db/models/sql/query.py
+++ b/django/db/models/sql/query.py
@@ -1369,6 +1369,7 @@ class Query:
return target_clause
def add_filtered_relation(self, filtered_relation, alias):
+ self.check_alias(alias)
filtered_relation.alias = alias
lookups = dict(get_children_from_q(filtered_relation.condition))
for lookup in chain((filtered_relation.relation_name,), lookups):
diff --git a/docs/releases/2.2.28.txt b/docs/releases/2.2.28.txt
index 0e092f0..f3fb298 100644
--- a/docs/releases/2.2.28.txt
+++ b/docs/releases/2.2.28.txt
@@ -117,3 +117,10 @@ which has now been updated to define a ``max_length`` of 39 characters.
The :class:`django.db.models.GenericIPAddressField` model field was not
affected.
+CVE-2025-57833: Potential SQL injection in ``FilteredRelation`` column aliases
+==============================================================================
+
+:class:`.FilteredRelation` was subject to SQL injection in column aliases,
+using a suitably crafted dictionary, with dictionary expansion, as the
+``**kwargs`` passed to :meth:`.QuerySet.annotate` or :meth:`.QuerySet.alias`.
+
diff --git a/tests/annotations/tests.py b/tests/annotations/tests.py
index 8082c7a..00d4ee6 100644
--- a/tests/annotations/tests.py
+++ b/tests/annotations/tests.py
@@ -4,7 +4,7 @@ from decimal import Decimal
from django.core.exceptions import FieldDoesNotExist, FieldError
from django.db.models import (
BooleanField, Case, CharField, Count, DateTimeField, DecimalField, Exists,
ExpressionWrapper, F, FloatField, Func, IntegerField, Max,
NullBooleanField, OuterRef, Q, Subquery, Sum, Value, When,
)
from django.db.models.expressions import RawSQL
@@ -775,6 +775,15 @@ class NonAggregateAnnotationTestCase(TestCase):
with self.assertRaisesMessage(ValueError, msg):
Book.objects.annotate(**{crafted_alias: Value(1)})
+ def test_alias_filtered_relation_sql_injection(self):
+ crafted_alias = """injected_name" from "annotations_book"; --"""
+ msg = (
+ "Column aliases cannot contain whitespace characters, quotation marks, "
+ "semicolons, or SQL comments."
+ )
+ with self.assertRaisesMessage(ValueError, msg):
+ Book.objects.annotate(**{crafted_alias: FilteredRelation("author")})
+
def test_alias_forbidden_chars(self):
tests = [
'al"ias',
@@ -800,6 +809,11 @@ class NonAggregateAnnotationTestCase(TestCase):
with self.assertRaisesMessage(ValueError, msg):
Book.objects.annotate(**{crafted_alias: Value(1)})
+ with self.assertRaisesMessage(ValueError, msg):
+ Book.objects.annotate(
+ **{crafted_alias: FilteredRelation("authors")}
+ )
+
class AliasTests(TestCase):
@classmethod
@@ -1039,3 +1053,12 @@ class AliasTests(TestCase):
)
with self.assertRaisesMessage(ValueError, msg):
Book.objects.alias(**{crafted_alias: Value(1)})
+
+ def test_alias_filtered_relation_sql_injection(self):
+ crafted_alias = """injected_name" from "annotations_book"; --"""
+ msg = (
+ "Column aliases cannot contain whitespace characters, quotation marks, "
+ "semicolons, or SQL comments."
+ )
+ with self.assertRaisesMessage(ValueError, msg):
+ Book.objects.alias(**{crafted_alias: FilteredRelation("authors")})
@@ -4,7 +4,7 @@ from decimal import Decimal
from django.db.models import (
BooleanField, Case, CharField, Count, DateTimeField, DecimalField, Exists,
- ExpressionWrapper, F, FloatField, Func, IntegerField, Max,
+ ExpressionWrapper, F, FilteredRelation, FloatField, Func, IntegerField, Max,
NullBooleanField, OuterRef, Q, Subquery, Sum, Value, When,
)
diff --git a/tests/annotations/tests.py b/tests/annotations/tests.py
index 27cd7eb..cdffb07 100644
--- a/tests/annotations/tests.py
+++ b/tests/annotations/tests.py
@@ -3,8 +3,8 @@ from decimal import Decimal
from django.core.exceptions import FieldDoesNotExist, FieldError
from django.db.models import (
BooleanField, CharField, Count, DateTimeField, ExpressionWrapper, F, Func,
IntegerField, NullBooleanField, OuterRef, Q, Subquery, Sum, Value,
)
from django.db.models.expressions import RawSQL
from django.db.models.functions import Length, Lower
@@ -608,6 +608,15 @@ class NonAggregateAnnotationTestCase(TestCase):
with self.assertRaisesMessage(ValueError, msg):
Book.objects.annotate(**{crafted_alias: Value(1)})
+ def test_alias_filtered_relation_sql_injection(self):
+ crafted_alias = """injected_name" from "annotations_book"; --"""
+ msg = (
+ "Column aliases cannot contain whitespace characters, quotation marks, "
+ "semicolons, or SQL comments."
+ )
+ with self.assertRaisesMessage(ValueError, msg):
+ Book.objects.annotate(**{crafted_alias: FilteredRelation("author")})
+
def test_alias_forbidden_chars(self):
tests = [
'al"ias',
@@ -632,3 +641,8 @@ class NonAggregateAnnotationTestCase(TestCase):
with self.subTest(crafted_alias):
with self.assertRaisesMessage(ValueError, msg):
Book.objects.annotate(**{crafted_alias: Value(1)})
+
+ with self.assertRaisesMessage(ValueError, msg):
+ Book.objects.annotate(
+ **{crafted_alias: FilteredRelation("authors")}
+ )
@@ -3,8 +3,8 @@ from decimal import Decimal
from django.core.exceptions import FieldDoesNotExist, FieldError
from django.db.models import (
- BooleanField, CharField, Count, DateTimeField, ExpressionWrapper, F, Func,
- IntegerField, NullBooleanField, OuterRef, Q, Subquery, Sum, Value,
+ BooleanField, CharField, Count, DateTimeField, ExpressionWrapper, F, FilteredRelation,
+ Func, IntegerField, NullBooleanField, OuterRef, Q, Subquery, Sum, Value,
)
from django.db.models.expressions import RawSQL
--
2.40.0

View File

@@ -27,6 +27,7 @@ SRC_URI += "file://CVE-2023-31047.patch \
file://CVE-2024-27351.patch \
file://CVE-2025-26699.patch \
file://CVE-2024-56374.patch \
file://CVE-2025-57833.patch \
"
SRC_URI[sha256sum] = "0200b657afbf1bc08003845ddda053c7641b9b24951e52acd51f6abda33a7413"

View File

@@ -9,6 +9,7 @@ RDEPENDS:${PN} += "\
SRC_URI += "\
file://CVE-2025-26699.patch \
file://CVE-2024-56374.patch \
file://CVE-2025-57833.patch \
"
# Set DEFAULT_PREFERENCE so that the LTS version of django is built by